This is the DLL from [the official python samples](https://github.com/TheImagingSource/IC-Imaging-Control-Samples/tree/master/Python/tisgrabber). According to 
[this issue](https://github.com/TheImagingSource/IC-Imaging-Control-Samples/issues/59) it
is version 3.5, currently not available from the official website.

